@@ -1,4 +1,4 @@
-;;; php-mode-autoloads.el --- automatically extracted autoloads
+;;; php-mode-autoloads.el --- automatically extracted autoloads  -*- lexical-binding: t -*-
 ;;
 ;;; Code:
 
@@ -40,7 +40,7 @@ Find php.ini FILE by `php --ini'.
 
 \(fn &optional FILE)" t nil)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php" '("php-")))
+(register-definition-prefixes "php" '("php-"))
 
 ;;;***
 
@@ -53,14 +53,23 @@ Setup alignment configuration for PHP code." nil nil)
 (autoload 'php-align-mode "php-align" "\
 Alignment lines for PHP script.
 
-If called interactively, enable Php-Align mode if ARG is
-positive, and disable it if ARG is zero or negative.  If called
-from Lisp, also enable the mode if ARG is omitted or nil, and
-toggle it if ARG is `toggle'; disable the mode otherwise.
+This is a minor mode.  If called interactively, toggle the
+`Php-Align mode' mode.  If the prefix argument is positive,
+enable the mode, and if it is zero or negative, disable the mode.
+
+If called from Lisp, toggle the mode if ARG is `toggle'.  Enable
+the mode if ARG is nil, omitted, or is a positive number.
+Disable the mode if ARG is a negative number.
+
+To check whether the minor mode is enabled in the current buffer,
+evaluate `php-align-mode'.
+
+The mode's hook is called both when the mode is enabled and when
+it is disabled.
 
 \(fn &optional ARG)" t nil)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-align" '("php-align-")))
+(register-definition-prefixes "php-align" '("php-align-"))
 
 ;;;***
 
@@ -69,7 +78,7 @@ toggle it if ARG is `toggle'; disable the mode otherwise.
 
 (let ((loads (get 'php-faces 'custom-loads))) (if (member '"php-face" loads) nil (put 'php-faces 'custom-loads (cons '"php-face" loads))))
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-face" '("php-annotations-annotation-face")))
+(register-definition-prefixes "php-face" '("php-annotations-annotation-face"))
 
 ;;;***
 
@@ -77,7 +86,18 @@ toggle it if ARG is `toggle'; disable the mode otherwise.
 ;;;;;;  0 0 0))
 ;;; Generated autoloads from php-local-manual.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-local-manual" '("php-local-manual-search")))
+(autoload 'php-local-manual-search "php-local-manual" "\
+Search the local PHP documentation (i.e. in `php-manual-path') for
+the word at point.  The function returns t if the requested documentation
+exists, and nil otherwise.
+
+With a prefix argument, prompt (with completion) for a word to search for.
+
+\(fn WORD)" t nil)
+
+(define-obsolete-function-alias 'php-search-local-documentation #'php-local-manual-search "2.0.0")
+
+(register-definition-prefixes "php-local-manual" '("php-local-manual-"))
 
 ;;;***
 
@@ -86,7 +106,7 @@ toggle it if ARG is `toggle'; disable the mode otherwise.
 
 (let ((loads (get 'php-mode 'custom-loads))) (if (member '"php-mode" loads) nil (put 'php-mode 'custom-loads (cons '"php-mode" loads))))
 
-(if (version< emacs-version "24.4") (dolist (i '("php" "php5" "php7")) (add-to-list 'interpreter-mode-alist (cons i 'php-mode))) (add-to-list 'interpreter-mode-alist (cons "php\\(?:-?[3457]\\(?:\\.[0-9]+\\)*\\)?" 'php-mode)))
+(add-to-list 'interpreter-mode-alist (cons "php\\(?:-?[34578]\\(?:\\.[0-9]+\\)*\\)?" 'php-mode))
 
 (define-obsolete-variable-alias 'php-available-project-root-files 'php-project-available-root-files "1.19.0")
 
@@ -103,7 +123,7 @@ Major mode for editing PHP code.
 
 (add-to-list 'auto-mode-alist '("\\.\\(?:php[s345]?\\|phtml\\)\\'" . php-mode-maybe))
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-mode" '("php-")))
+(register-definition-prefixes "php-mode" '("php-"))
 
 ;;;***
 
@@ -111,7 +131,7 @@ Major mode for editing PHP code.
 ;;;;;;  0))
 ;;; Generated autoloads from php-mode-debug.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-mode-debug" '("php-mode-debug")))
+(register-definition-prefixes "php-mode-debug" '("php-mode-debug"))
 
 ;;;***
 
@@ -217,7 +237,14 @@ Return list of bootstrap script." nil nil)
 (autoload 'php-project-get-root-dir "php-project" "\
 Return path to current PHP project." nil nil)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "php-project" '("php-project-")))
+(autoload 'php-project-project-find-function "php-project" "\
+Return path to current PHP project from DIR.
+
+This function is compatible with `project-find-functions'.
+
+\(fn DIR)" nil nil)
+
+(register-definition-prefixes "php-project" '("php-project-"))
 
 ;;;***
 
